print("import: 'grpc'")
import grpc

print("import: 'grpc.beta'")
import grpc.beta

print("import: 'grpc.framework'")
import grpc.framework

print("import: 'grpc.framework.common'")
import grpc.framework.common

print("import: 'grpc.framework.foundation'")
import grpc.framework.foundation

print("import: 'grpc.framework.interfaces'")
import grpc.framework.interfaces

print("import: 'grpc.framework.interfaces.base'")
import grpc.framework.interfaces.base

print("import: 'grpc.framework.interfaces.face'")
import grpc.framework.interfaces.face

